@@ -1,6 +1,5 @@
 use std::cmp;
 use std::collections::HashMap;
-use std::io::Write;
 
 use gitql_ast::expression::Expr;
 use gitql_ast::expression::ExprKind;
@@ -31,6 +30,7 @@ use crate::engine_filter::apply_filter_operation;
 use crate::engine_group::execute_group_by_statement;
 use crate::engine_join::apply_join_operation;
 use crate::engine_ordering::execute_order_by_statement;
+use crate::engine_output_into::execute_into_statement;
 
 #[allow(clippy::borrowed_box)]
 pub fn execute_statement(
@@ -463,57 +463,6 @@ fn execute_aggregation_function_statement(
     Ok(())
 }
 
-fn execute_into_statement(
-    statement: &IntoStatement,
-    gitql_object: &mut GitQLObject,
-) -> Result<(), String> {
-    let mut buffer = String::new();
-
-    let line_terminated_by = &statement.lines_terminated;
-    let field_termianted_by = &statement.fields_terminated;
-    let enclosing = &statement.enclosed;
-
-    // Headers
-    let header = gitql_object.titles.join(field_termianted_by);
-    buffer.push_str(&header);
-    buffer.push_str(line_terminated_by);
-
-    // Rows of the main group
-    if let Some(main_group) = gitql_object.groups.first() {
-        for row in &main_group.rows {
-            let row_values: Vec<String> = row
-                .values
-                .iter()
-                .map(|r| value_to_string_with_optional_enclosing(r, enclosing))
-                .collect();
-            buffer.push_str(&row_values.join(field_termianted_by));
-            buffer.push_str(line_terminated_by);
-        }
-    }
-
-    let file_result = std::fs::File::create(statement.file_path.clone());
-    if let Err(error) = file_result {
-        return Err(error.to_string());
-    }
-
-    let mut file = file_result.ok().unwrap();
-    let write_result = file.write_all(buffer.as_bytes());
-    if let Err(error) = write_result {
-        return Err(error.to_string());
-    }
-
-    Ok(())
-}
-
-#[inline(always)]
-#[allow(clippy::borrowed_box)]
-fn value_to_string_with_optional_enclosing(value: &Box<dyn Value>, enclosed: &String) -> String {
-    if enclosed.is_empty() {
-        return value.literal();
-    }
-    format!("{}{}{}", enclosed, value.literal(), enclosed)
-}
-
 pub fn execute_global_variable_statement(
     env: &mut Environment,
     statement: &GlobalVariableStatement,
