@@ -2,7 +2,8 @@ use std::collections::HashMap;
 
 use gitql_ast::statement::AggregateValue;
 
-use crate::tokenizer::Location;
+use crate::name_generator::NameGenerator;
+use crate::token::SourceLocation;
 
 #[derive(Default)]
 pub struct ParserContext {
@@ -13,9 +14,10 @@ pub struct ParserContext {
 
     pub selected_tables: Vec<String>,
     pub projection_names: Vec<String>,
-    pub projection_locations: Vec<Location>,
+    pub projection_locations: Vec<SourceLocation>,
 
     pub name_alias_table: HashMap<String, String>,
+    pub name_generator: NameGenerator,
 
     pub has_select_statement: bool,
     pub is_single_value_query: bool,
