@@ -1,8 +1,11 @@
 pub mod context;
 pub mod diagnostic;
-pub mod tokenizer;
+pub mod name_generator;
 pub mod type_checker;
 
+pub mod token;
+pub mod tokenizer;
+
 pub(crate) mod parse_cast;
 pub(crate) mod parse_type;
 pub mod parser;
