@@ -1,3 +1,4 @@
+use std::fs;
 use std::io;
 use std::io::IsTerminal;
 
@@ -22,7 +23,7 @@ use gitql_engine::engine;
 use gitql_engine::engine::EvaluationResult::SelectedGroups;
 use gitql_parser::diagnostic::Diagnostic;
 use gitql_parser::parser;
-use gitql_parser::tokenizer;
+use gitql_parser::tokenizer::Tokenizer;
 use gitql_std::aggregation::aggregation_function_signatures;
 use gitql_std::aggregation::aggregation_functions;
 use lineeditor::LineEditorResult;
@@ -45,6 +46,30 @@ fn main() {
         Command::ReplMode(arguments) => {
             launch_gitql_repl(arguments);
         }
+        Command::ScriptMode(script_file, arguments) => {
+            let mut reporter = diagnostic_reporter::DiagnosticReporter::default();
+            let git_repos_result = validate_git_repositories(&arguments.repos);
+
+            let repos = git_repos_result.ok().unwrap();
+            let schema = Schema {
+                tables_fields_names: tables_fields_names().to_owned(),
+                tables_fields_types: tables_fields_types().to_owned(),
+            };
+
+            let std_signatures = git_functions::gitql_std_signatures();
+            let std_functions = git_functions::gitql_std_functions();
+
+            let aggregation_signatures = aggregation_function_signatures();
+            let aggregation_functions = aggregation_functions();
+
+            let mut env = Environment::new(schema);
+            env.with_standard_functions(&std_signatures, std_functions);
+            env.with_aggregation_functions(&aggregation_signatures, aggregation_functions);
+
+            let query =
+                fs::read_to_string(script_file).expect("Should have been able to read the file");
+            execute_gitql_query(query, &arguments, &repos, &mut env, &mut reporter);
+        }
         Command::QueryMode(query, arguments) => {
             let mut reporter = diagnostic_reporter::DiagnosticReporter::default();
             let git_repos_result = validate_git_repositories(&arguments.repos);
@@ -196,7 +221,7 @@ fn execute_gitql_query(
     reporter: &mut DiagnosticReporter,
 ) {
     let front_start = std::time::Instant::now();
-    let tokenizer_result = tokenizer::tokenize(query.clone());
+    let tokenizer_result = Tokenizer::tokenize(query.clone());
     if tokenizer_result.is_err() {
         let diagnostic = tokenizer_result.err().unwrap();
         reporter.report_diagnostic(&query, *diagnostic);
@@ -225,34 +250,35 @@ fn execute_gitql_query(
 
     // Report Runtime exceptions if they exists
     if evaluation_result.is_err() {
-        reporter.report_diagnostic(
-            &query,
-            Diagnostic::exception(&evaluation_result.err().unwrap()),
-        );
+        let exception = Diagnostic::exception(&evaluation_result.err().unwrap());
+        reporter.report_diagnostic(&query, exception);
         return;
     }
 
-    // Render the result only if they are selected groups not any other statement
-    let mut rows_count = 0;
-    let engine_result = evaluation_result.ok().unwrap();
-    if let SelectedGroups(mut groups) = engine_result {
-        rows_count += groups.len();
-        let printer: Box<dyn OutputPrinter> = match arguments.output_format {
-            OutputFormat::Render => {
-                Box::new(TablePrinter::new(arguments.pagination, arguments.page_size))
-            }
-            OutputFormat::JSON => Box::new(JSONPrinter {}),
-            OutputFormat::CSV => Box::new(CSVPrinter {}),
-        };
-        printer.print(&mut groups);
-    }
+    let printer: Box<dyn OutputPrinter> = match arguments.output_format {
+        OutputFormat::Render => {
+            Box::new(TablePrinter::new(arguments.pagination, arguments.page_size))
+        }
+        OutputFormat::JSON => Box::new(JSONPrinter {}),
+        OutputFormat::CSV => Box::new(CSVPrinter {}),
+    };
 
-    if arguments.analysis {
-        let total_time = front_duration + engine_duration;
-        println!(
-            "{} row in set (total: {:?}, front: {:?}, engine: {:?})",
-            rows_count, total_time, front_duration, engine_duration
-        );
+    // Render the result only if they are selected groups not any other statement
+    let evaluations_results = evaluation_result.ok().unwrap();
+    for evaluation_result in evaluations_results {
+        let mut rows_count = 0;
+        if let SelectedGroups(mut groups) = evaluation_result {
+            rows_count += groups.len();
+            printer.print(&mut groups);
+        }
+
+        if arguments.analysis {
+            let total_time = front_duration + engine_duration;
+            println!(
+                "{} row in set (total: {:?}, front: {:?}, engine: {:?})",
+                rows_count, total_time, front_duration, engine_duration
+            );
+        }
     }
 }
 
